Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7782)

Unified Diff: chrome/browser/ui/webui/bidi_checker_web_ui_test.h

Issue 9701086: Adjust signatures to pass string rather than char* since it ultimately constructs a GURL. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/webui/bidi_checker_web_ui_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/bidi_checker_web_ui_test.h
diff --git a/chrome/browser/ui/webui/bidi_checker_web_ui_test.h b/chrome/browser/ui/webui/bidi_checker_web_ui_test.h
index 594e4a76a64c4f94ba08539959a7e304cd0d3a25..b4a107fce6e7ca2fc7690f17361d753d9ba17c16 100644
--- a/chrome/browser/ui/webui/bidi_checker_web_ui_test.h
+++ b/chrome/browser/ui/webui/bidi_checker_web_ui_test.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -6,6 +6,8 @@
#define CHROME_BROWSER_UI_WEBUI_BIDI_CHECKER_WEB_UI_TEST_H_
#pragma once
+#include <string>
+
#include "chrome/browser/ui/webui/web_ui_browsertest.h"
#include "chrome/test/base/in_process_browser_test.h"
@@ -18,9 +20,9 @@ class WebUIBidiCheckerBrowserTest : public WebUIBrowserTest {
protected:
WebUIBidiCheckerBrowserTest();
// Runs the Bidi Checker on the given page URL. |isRTL| should be true when
// the active page locale is RTL.
- void RunBidiCheckerOnPage(const char pageURL[], bool isRTL);
+ void RunBidiCheckerOnPage(const std::string& page_url, bool is_rtl);
// Setup test path.
virtual void SetUpInProcessBrowserTestFixture() OVERRIDE;
@@ -29,13 +31,13 @@ class WebUIBidiCheckerBrowserTest : public WebUIBrowserTest {
// Base class for BidiChecker-based tests that run with an LTR UI.
class WebUIBidiCheckerBrowserTestLTR : public WebUIBidiCheckerBrowserTest {
public:
- void RunBidiCheckerOnPage(const char pageURL[]);
+ void RunBidiCheckerOnPage(const std::string& page_url);
};
// Base class for BidiChecker-based tests that run with an RTL UI.
class WebUIBidiCheckerBrowserTestRTL : public WebUIBidiCheckerBrowserTest {
public:
- void RunBidiCheckerOnPage(const char pageURL[]);
+ void RunBidiCheckerOnPage(const std::string& page_url);
protected:
virtual void SetUpOnMainThread() OVERRIDE;
« no previous file with comments | « no previous file | chrome/browser/ui/webui/bidi_checker_web_ui_test.cc » ('j') | no next file with comments »
@@ -18,9 +20,9 @@ class WebUIBidiCheckerBrowserTest : public WebUIBrowserTest {
protected:
WebUIBidiCheckerBrowserTest();
- // Runs the Bidi Checker on the given page URL. |isRTL| should be true when
+ // Runs the Bidi Checker on the given page URL. |is_rtl| should be true when
// the active page locale is RTL.

Powered by Google App Engine
This is Rietveld 408576698